@@ -11,19 +11,29 @@ TARGETLIST_URL = ("http://www.astro.washington.edu/users/ivezic/"
                   "linear/allDataFinal/allLINEARfinal_targets.dat")
 DATA_URL = ("http://www.astro.washington.edu/users/ivezic/"
             "linear/allDataFinal/allLINEARfinal_dat.tar.gz")
-GENEVA_URL = ("http://www.astro.washington.edu/users/ivezic/"
-              "DMbook/data/LINEARattributes.dat")
-GENEVA_ARCHIVE = 'LINEARattributes.npy'
 
-ARCHIVE_DTYPE = [(s, 'f8') for s in ('RA', 'Dec', 'ug', 'gi', 'iK',
-                                     'JK', 'logP', 'amp', 'skew')]
+# old version of the data
+#GENEVA_URL = ("http://www.astro.washington.edu/users/ivezic/"
+#              "DMbook/data/LINEARattributes.dat"
+#GENEVA_ARCHIVE = 'LINEARattributes.npy'
+#ARCHIVE_DTYPE = [(s, 'f8') for s in ('RA', 'Dec', 'ug', 'gi', 'iK',
+#                                     'JK', 'logP', 'amp', 'skew')]
+
+GENEVA_URL = ("http://www.astro.washington.edu/users/ivezic/"
+              "DMbook/data/LINEARattributesFinalApr2013.dat")
+GENEVA_ARCHIVE = 'LINEARattributesFinalApr2013.npy'
+ARCHIVE_DTYPE = ([(s, 'f8') for s in ('RA', 'Dec', 'ug', 'gi', 'iK',
+                                     'JK', 'logP', 'amp', 'skew',
+                                     'kurt', 'magMed', 'nObs')]
+                 + [('LCtype', 'i4'), ('LINEARobjectID', '|S20')])
+
 
 target_names = ['objectID', 'raLIN', 'decLIN', 'raSDSS', 'decSDSS', 'r',
                 'ug', 'gr', 'ri', 'iz', 'JK', '<mL>', 'std', 'rms',
                 'Lchi2', 'LP1', 'phi1', 'S', 'prior']
 
 
-class LINEARdata:
+class LINEARdata(object):
     """A container class for the linear dataset.
 
     Because the dataset is often not needed all at once, this class
