@@ -45,8 +45,8 @@ def fetch_rrlyrae_mags(data_home=None, download_if_missing=True):
     -----
     This data is from table 1 of Sesar et al 2010 ApJ 708:717
     """
-    # pyfits is an optional dependency: don't import globally
-    import pyfits
+    # fits is an optional dependency: don't import globally
+    from astropy.io import fits
 
     data_home = get_data_home(data_home)
     if not os.path.exists(data_home):
@@ -62,7 +62,7 @@ def fetch_rrlyrae_mags(data_home=None, download_if_missing=True):
         fitsdata = download_with_progress_bar(DATA_URL)
         open(archive_file, 'wb').write(fitsdata)
 
-    hdulist = pyfits.open(archive_file)
+    hdulist = fits.open(archive_file)
     return np.asarray(hdulist[1].data)
 
 
