@@ -81,8 +81,8 @@ def fetch_sdss_specgals(data_home=None, download_if_missing=True):
     >>> print data['dec'][:3]  #  first three declination values
     [-1.04127639 -0.6522198  -0.7651468 ]
     """
-    # pyfits is an optional dependency: don't import globally
-    import pyfits
+    # fits is an optional dependency: don't import globally
+    from astropy.io import fits
 
     data_home = get_data_home(data_home)
     if not os.path.exists(data_home):
@@ -98,7 +98,7 @@ def fetch_sdss_specgals(data_home=None, download_if_missing=True):
         fitsdata = download_with_progress_bar(DATA_URL)
         open(archive_file, 'wb').write(fitsdata)
 
-    hdulist = pyfits.open(archive_file)
+    hdulist = fits.open(archive_file)
     return np.asarray(hdulist[1].data)
 
 
