@@ -1,6 +1,7 @@
 """
 Example of a Binomial distribution
 ----------------------------------
+Figure 3.9.
 
 This shows an example of a binomial distribution with various parameters.
 We'll generate the distribution using::
@@ -23,15 +24,25 @@ distribution objects have many useful methods; for example:
 Many further options exist; refer to the documentation of ``scipy.stats``
 for more details.
 """
-# Author: Jake VanderPlas <vanderplas@astro.washington.edu>
+# Author: Jake VanderPlas
 # License: BSD
 #   The figure produced by this code is published in the textbook
 #   "Statistics, Data Mining, and Machine Learning in Astronomy" (2013)
 #   For more information, see http://astroML.github.com
+#   To report a bug or issue, use the following forum:
+#    https://groups.google.com/forum/#!forum/astroml-general
 import numpy as np
 from scipy.stats import binom
 from matplotlib import pyplot as plt
 
+#----------------------------------------------------------------------
+# This function adjusts matplotlib settings for a uniform feel in the textbook.
+# Note that with usetex=True, fonts are rendered with LaTeX.  This may
+# result in an error if LaTeX is not installed on your system.  In that case,
+# you can set usetex to False.
+from astroML.plotting import setup_text_plots
+setup_text_plots(fontsize=8, usetex=True)
+
 #------------------------------------------------------------
 # Define the distribution parameters to be plotted
 n_values = [20, 20, 40]
@@ -41,6 +52,8 @@ x = np.arange(-1, 200)
 
 #------------------------------------------------------------
 # plot the distributions
+fig, ax = plt.subplots(figsize=(5, 3.75))
+
 for (n, b, ls) in zip(n_values, b_values, linestyles):
     # create a binomial distribution
     dist = binom(n, b)
@@ -48,11 +61,11 @@ for (n, b, ls) in zip(n_values, b_values, linestyles):
     plt.plot(x, dist.pmf(x), ls=ls, c='black',
              label=r'$b=%.1f,\ n=%i$' % (b, n), linestyle='steps-mid')
 
-plt.xlim(-0.5, 40)
-plt.ylim(0, 0.3)
+plt.xlim(-0.5, 35)
+plt.ylim(0, 0.25)
 
-plt.xlabel('$x$', fontsize=14)
-plt.ylabel(r'$P(x|b, n)$', fontsize=14)
+plt.xlabel('$x$')
+plt.ylabel(r'$p(x|b, n)$')
 plt.title('Binomial Distribution')
 
 plt.legend()
