@@ -1,21 +1,46 @@
 r"""
-Random Number Generation
-------------------------
+Random Values from an Empirical Distribution
+--------------------------------------------
+Figure 3.25.
 
-This example shows how to clone a measured 1-dimensional distribution
-using :class:`astroML.density_estimation.EmpiricalDistribution`
+A demonstration of how to empirically clone a distribution, using a spline
+interpolation to approximate the inverse of the observed cumulative
+distribution. This allows us to nonparametrically select new random samples
+approximating an observed distribution. First the list of points is sorted,
+and the rank of each point is used to approximate the cumulative distribution
+(upper right). Flipping the axes gives the inverse cumulative distribution on
+a regular grid (lower left). After performing a cubic spline fit to the inverse
+distribution, a uniformly sampled x value maps to a y value which approximates
+the observed pdf. The lower-right panel shows the result. The K-S test
+(see section 4.7.2) indicates that the samples are consistent with being
+drawn from the same distribution. This method, while fast and effective,
+cannot be easily extended to multiple dimensions.
+
+This example uses the routine
+:class:`astroML.density_estimation.EmpiricalDistribution`
+to clone the distribution
 """
-# Author: Jake VanderPlas <vanderplas@astro.washington.edu>
+# Author: Jake VanderPlas
 # License: BSD
 #   The figure produced by this code is published in the textbook
 #   "Statistics, Data Mining, and Machine Learning in Astronomy" (2013)
 #   For more information, see http://astroML.github.com
+#   To report a bug or issue, use the following forum:
+#    https://groups.google.com/forum/#!forum/astroml-general
 import numpy as np
 from matplotlib import pyplot as plt
 from scipy import stats, interpolate
 from astroML.plotting import hist
 from astroML.density_estimation import EmpiricalDistribution
 
+#----------------------------------------------------------------------
+# This function adjusts matplotlib settings for a uniform feel in the textbook.
+# Note that with usetex=True, fonts are rendered with LaTeX.  This may
+# result in an error if LaTeX is not installed on your system.  In that case,
+# you can set usetex to False.
+from astroML.plotting import setup_text_plots
+setup_text_plots(fontsize=8, usetex=True)
+
 #------------------------------------------------------------
 # Create a distribution and clone it
 Ndata = 1000
@@ -51,8 +76,8 @@ x_sample = interpolate.splev(Px_cuml_sample, tck)
 
 #------------------------------------------------------------
 # Plot the cloned distribution and the procedure for obtaining it
-fig = plt.figure(figsize=(10, 10))
-fig.subplots_adjust(hspace=0.25, left=0.1, right=0.95,
+fig = plt.figure(figsize=(5, 5))
+fig.subplots_adjust(hspace=0.3, left=0.1, right=0.95,
                     bottom=0.08, top=0.92)
 
 indices = np.linspace(0, Ndata - 1, 20).astype(int)
@@ -68,7 +93,7 @@ ax.set_ylabel('$N(x)$')
 
 # plot the cumulative distribution
 ax = fig.add_subplot(222)
-ax.scatter(x[indices], Px_cuml[indices], lw=0, c='k')
+ax.scatter(x[indices], Px_cuml[indices], lw=0, c='k', s=9)
 ax.plot(x, Px_cuml, '-k')
 ax.set_xlim(-3, 3)
 ax.set_ylim(-0.05, 1.05)
@@ -78,10 +103,12 @@ ax.set_ylabel('$p(<x)$')
 
 # plot the inverse cumulative distribution and spline fit
 ax = fig.add_subplot(223)
-ax.scatter(Px_cuml[indices], x[indices], lw=0, c='k')
+ax.scatter(Px_cuml[indices], x[indices], lw=0, c='k', s=9)
 ax.plot(Px_cuml_sample, x_sample, '-k')
-ax.arrow(0.7, -3, 0, 3.5, width=0.015, fc='gray', ec='gray', head_length=0.4)
-ax.arrow(0.7, 0.9, -0.69, 0, width=0.1, fc='gray', ec='gray', head_length=0.06)
+ax.arrow(0.7, -3, 0, 3.5, width=0.015, fc='gray', ec='gray',
+         head_width=0.05, head_length=0.4)
+ax.arrow(0.7, 0.9, -0.69, 0, width=0.1, fc='gray', ec='gray',
+         head_width=0.3, head_length=0.06)
 ax.set_xlim(-0.05, 1.05)
 ax.set_ylim(-3, 3)
 ax.set_title('Inverse Cuml. Distribution')
