@@ -1,6 +1,7 @@
 """
 Example of a Poisson distribution
 ----------------------------------
+Figure 3.10.
 
 This shows an example of a Poisson distribution with various parameters.
 We'll generate the distribution using::
@@ -23,15 +24,25 @@ distribution objects have many useful methods; for example:
 Many further options exist; refer to the documentation of ``scipy.stats``
 for more details.
 """
-# Author: Jake VanderPlas <vanderplas@astro.washington.edu>
+# Author: Jake VanderPlas
 # License: BSD
 #   The figure produced by this code is published in the textbook
 #   "Statistics, Data Mining, and Machine Learning in Astronomy" (2013)
 #   For more information, see http://astroML.github.com
+#   To report a bug or issue, use the following forum:
+#    https://groups.google.com/forum/#!forum/astroml-general
 import numpy as np
 from scipy.stats import poisson
 from matplotlib import pyplot as plt
 
+#----------------------------------------------------------------------
+# This function adjusts matplotlib settings for a uniform feel in the textbook.
+# Note that with usetex=True, fonts are rendered with LaTeX.  This may
+# result in an error if LaTeX is not installed on your system.  In that case,
+# you can set usetex to False.
+from astroML.plotting import setup_text_plots
+setup_text_plots(fontsize=8, usetex=True)
+
 #------------------------------------------------------------
 # Define the distribution parameters to be plotted
 mu_values = [1, 5, 15]
@@ -45,6 +56,8 @@ linestyles = ['-', '--', ':']
 #     discrete distributions.
 #   - dist.pdf(x) evaluates the probability density function for
 #   evaluates
+fig, ax = plt.subplots(figsize=(5, 3.75))
+
 for mu, ls in zip(mu_values, linestyles):
     # create a poisson distribution
     # we could generate a random sample from this distribution using, e.g.
@@ -58,8 +71,8 @@ for mu, ls in zip(mu_values, linestyles):
 plt.xlim(-0.5, 30)
 plt.ylim(0, 0.4)
 
-plt.xlabel('$x$', fontsize=14)
-plt.ylabel(r'$P(x|\mu)$', fontsize=14)
+plt.xlabel('$x$')
+plt.ylabel(r'$p(x|\mu)$')
 plt.title('Poisson Distribution')
 
 plt.legend()
