@@ -1,17 +1,26 @@
 """
 Lynden-Bell Luminosity function
 -------------------------------
+Figure 4.10.
 
-This shows the use of Lynden-Bell's C- method for computing the luminosity
-function and redshift distribution from an observed sample of galaxies.
-
-We work with x=Magnitude, y=redshift.
+An example of computing the luminosity function for two u-r color-selected
+subsamples of SDSS galaxies using Lynden-Bell's C- method. The galaxies are
+selected from the SDSS spectroscopic sample, with redshift in the range
+0.08 < z < 0.12 and flux limited to r < 17.7. The left panels show the
+distribution of sources as a function of redshift and absolute magnitude. The
+distribution p(z, M) = rho(z) Phi(m) is obtained using Lynden-Bell's method,
+with errors determined by 20 bootstrap resamples. The results are shown in the
+right panels. For the redshift distribution, we multiply the result by z^2 for
+clarity. Note that the most luminous galaxies belong to the photometrically
+red subsample, as discernible in the bottom-right panel.
 """
-# Author: Jake VanderPlas <vanderplas@astro.washington.edu>
+# Author: Jake VanderPlas
 # License: BSD
 #   The figure produced by this code is published in the textbook
 #   "Statistics, Data Mining, and Machine Learning in Astronomy" (2013)
 #   For more information, see http://astroML.github.com
+#   To report a bug or issue, use the following forum:
+#    https://groups.google.com/forum/#!forum/astroml-general
 import os
 import numpy as np
 from matplotlib import pyplot as plt
@@ -22,6 +31,14 @@ from astroML.lumfunc import binned_Cminus, bootstrap_Cminus
 from astroML.cosmology import Cosmology
 from astroML.datasets import fetch_sdss_specgals
 
+#----------------------------------------------------------------------
+# This function adjusts matplotlib settings for a uniform feel in the textbook.
+# Note that with usetex=True, fonts are rendered with LaTeX.  This may
+# result in an error if LaTeX is not installed on your system.  In that case,
+# you can set usetex to False.
+from astroML.plotting import setup_text_plots
+setup_text_plots(fontsize=8, usetex=True)
+
 #------------------------------------------------------------
 # Get the data and perform redshift/magnitude cuts
 data = fetch_sdss_specgals()
@@ -103,9 +120,9 @@ def compute_luminosity_function(z, m, M, m_max, archive_file):
 
 #------------------------------------------------------------
 # Perform the computation and plot the results
-fig = plt.figure(figsize=(8, 8))
-fig.subplots_adjust(left=0.12, right=0.95, wspace=0.3,
-                    bottom=0.07, top=0.95, hspace=0.2)
+fig = plt.figure(figsize=(5, 5))
+fig.subplots_adjust(left=0.13, right=0.95, wspace=0.3,
+                    bottom=0.08, top=0.95, hspace=0.2)
 
 for i in range(2):
     m = data[i]['petroMag_r']
@@ -145,7 +162,7 @@ for i in range(2):
     factor = 0.08 ** 2 / (0.5 * (zbins[1:] + zbins[:-1])) ** 2
     ax2.errorbar(0.5 * (zbins[1:] + zbins[:-1]),
                  factor * dist_z, factor * err_z,
-                 fmt='-k' + markers[i], ecolor='gray', lw=1,
+                 fmt='-k' + markers[i], ecolor='gray', lw=1, ms=4,
                  label=titles[i])
 
     #------------------------------------------------------------
@@ -158,19 +175,19 @@ for i in range(2):
     err_M = err_M[3:-1]
 
     ax3.errorbar(0.5 * (Mbins[1:] + Mbins[:-1]), dist_M, err_M,
-                 fmt='-k' + markers[i], ecolor='gray', lw=1,
+                 fmt='-k' + markers[i], ecolor='gray', lw=1, ms=4,
                  label=titles[i])
 
 #------------------------------------------------------------
 # set labels and limits
-ax2.legend(loc=1, prop=dict(size=14))
+ax2.legend(loc=1)
 ax2.xaxis.set_major_locator(plt.MultipleLocator(0.01))
 ax2.set_xlabel(r'$z$')
 ax2.set_ylabel(r'$\rho(z) / [z / 0.08]^2$')
 ax2.set_xlim(0.075, 0.125)
 ax2.set_ylim(10, 25)
 
-ax3.legend(loc=3, prop=dict(size=14))
+ax3.legend(loc=3)
 ax3.xaxis.set_major_locator(plt.MultipleLocator(1.0))
 ax3.set_xlabel(r'$M$')
 ax3.set_ylabel(r'$\Phi(M)$')
