@@ -1,16 +1,25 @@
 """
 Extreme Deconvolution of Stellar Data
 -------------------------------------
-This figure demonstrates the use of Extreme Deconvolution on real stellar
-data.  We compare the single-epoch photometry from SDSS to the multi-epoch
-photometry from stripe 82.  The extreme deconvolution recovers the
-underlying non-noisy distribution.
+Figure 6.12
+
+Extreme deconvolution applied to stellar data from SDSS Stripe 82. The top
+panels compare the color distributions for a high signal-to-noise sample of
+standard stars (left) with lower signal-to-noise, single epoch, data (right).
+The middle panels show the results of applying extreme deconvolution to the
+single epoch data. The bottom panel compares the distributions of a color
+measured perpendicularly to the locus (the so-called w color is defined
+following Ivezic et al 2004). The distribution of colors from the extreme
+deconvolution of the noisy data recovers the tight distribution of the high
+signal-to-noise data.
 """
-# Author: Jake VanderPlas <vanderplas@astro.washington.edu>
+# Author: Jake VanderPlas
 # License: BSD
 #   The figure produced by this code is published in the textbook
 #   "Statistics, Data Mining, and Machine Learning in Astronomy" (2013)
 #   For more information, see http://astroML.github.com
+#   To report a bug or issue, use the following forum:
+#    https://groups.google.com/forum/#!forum/astroml-general
 import numpy as np
 from matplotlib import pyplot as plt
 
@@ -21,6 +30,14 @@ from astroML.plotting.tools import draw_ellipse
 from astroML.decorators import pickle_results
 from astroML.stats import sigmaG
 
+#----------------------------------------------------------------------
+# This function adjusts matplotlib settings for a uniform feel in the textbook.
+# Note that with usetex=True, fonts are rendered with LaTeX.  This may
+# result in an error if LaTeX is not installed on your system.  In that case,
+# you can set usetex to False.
+from astroML.plotting import setup_text_plots
+setup_text_plots(fontsize=8, usetex=True)
+
 #------------------------------------------------------------
 # define u-g-r-i-z extinction from Berry et al, arXiv 1111.4985
 # multiply extinction by A_r
@@ -141,8 +158,8 @@ X_sample = clf.sample(X.shape[0])
 
 #------------------------------------------------------------
 # plot the results
-fig = plt.figure()
-fig.subplots_adjust(left=0.1, right=0.95,
+fig = plt.figure(figsize=(5, 3.75))
+fig.subplots_adjust(left=0.12, right=0.95,
                     bottom=0.1, top=0.95,
                     wspace=0.02, hspace=0.02)
 
@@ -188,7 +205,7 @@ for i in range(4):
 
 #------------------------------------------------------------
 # Second figure: the width of the locus
-fig = plt.figure()
+fig = plt.figure(figsize=(5, 3.75))
 ax = fig.add_subplot(111)
 
 labels = ['single epoch', 'standard stars', 'XD resampled']
@@ -216,7 +233,7 @@ for data, label, ls in zip((X, Y, X_sample), labels, linestyles):
 
 ax.legend(loc=2)
 ax.text(0.95, 0.95, '$w = -0.227g + 0.792r$\n$ - 0.567i + 0.05$',
-        transform=ax.transAxes, ha='right', va='top', size=14)
+        transform=ax.transAxes, ha='right', va='top')
 
 ax.set_xlim(-0.07, 0.07)
 ax.set_ylim(0, 55)
