@@ -1,13 +1,23 @@
 """
 SDSS spectra Decompositions
 ---------------------------
-Comparison of PCA, ICA, and NMF decompositions of SDSS spectra
+Figure 7.4
+
+A comparison of the decomposition of SDSS spectra using PCA (left panel -
+see Section 7.3.1), ICA (middle panel - see Section 7.6) and NMF (right panel
+- see Section 7.4). The rank of the component increases from top to bottom. For
+the ICA and PCA the first component is the mean spectrum (NMF does not require
+mean subtraction). All of these techniques isolate a common set of spectral
+features (identifying features associated with the continuum and line
+emission). The ordering of the spectral components is technique dependent.
 """
-# Author: Jake VanderPlas <vanderplas@astro.washington.edu>
+# Author: Jake VanderPlas
 # License: BSD
 #   The figure produced by this code is published in the textbook
 #   "Statistics, Data Mining, and Machine Learning in Astronomy" (2013)
 #   For more information, see http://astroML.github.com
+#   To report a bug or issue, use the following forum:
+#    https://groups.google.com/forum/#!forum/astroml-general
 import numpy as np
 from matplotlib import pyplot as plt
 
@@ -18,6 +28,14 @@ from sklearn.decomposition import RandomizedPCA
 from astroML.datasets import sdss_corrected_spectra
 from astroML.decorators import pickle_results
 
+#----------------------------------------------------------------------
+# This function adjusts matplotlib settings for a uniform feel in the textbook.
+# Note that with usetex=True, fonts are rendered with LaTeX.  This may
+# result in an error if LaTeX is not installed on your system.  In that case,
+# you can set usetex to False.
+from astroML.plotting import setup_text_plots
+setup_text_plots(fontsize=8, usetex=True)
+
 #------------------------------------------------------------
 # Download data
 data = sdss_corrected_spectra.fetch_sdss_corrected_spectra()
@@ -58,7 +76,7 @@ decompositions = compute_PCA_ICA_NMF(n_components)
 
 #----------------------------------------------------------------------
 # Plot the results
-fig = plt.figure(figsize=(10, 8))
+fig = plt.figure(figsize=(5, 4))
 fig.subplots_adjust(left=0.05, right=0.95, wspace=0.05,
                     bottom=0.1, top=0.95, hspace=0.05)
 
@@ -83,7 +101,7 @@ for i, comp in enumerate(decompositions):
         ax.set_xlim(xlim)
 
         if j == 0:
-            ax.set_title(titles[i], fontsize='medium')
+            ax.set_title(titles[i])
 
         if titles[i].startswith('PCA') or titles[i].startswith('ICA'):
             if j == 0:
@@ -93,9 +111,11 @@ for i, comp in enumerate(decompositions):
         else:
             label = 'component %i' % (j + 1)
 
-        ax.text(0.02, 0.95, label, transform=ax.transAxes,
-                ha='left', va='top', bbox=dict(ec='w', fc='w'),
-                fontsize='small')
+        ax.text(0.03, 0.94, label, transform=ax.transAxes,
+                ha='left', va='top')
+
+        for l in ax.get_xticklines() + ax.get_yticklines(): 
+            l.set_markersize(2) 
 
         # adjust y limits
         ylim = plt.ylim()
