@@ -1,15 +1,19 @@
 """
 Decision Tree Classification of photometry
 ------------------------------------------
-Decision Tree photometric classification of rr-lyrae stars.  This uses averaged
-photometry from the rr-lyrae catalog and stripe 82 standards catalogs.  The
-results show the axis-aligned nature of the basic decision tree algorithm
+Figure 9.13
+
+Decision tree applied to the RR Lyrae data (see caption of figure 9.3 for
+details). This example uses tree depths of 7 and 12. With all four colors,this
+decision tree achieves a completeness of 0.569 and a contamination of 0.386.
 """
-# Author: Jake VanderPlas <vanderplas@astro.washington.edu>
+# Author: Jake VanderPlas
 # License: BSD
 #   The figure produced by this code is published in the textbook
 #   "Statistics, Data Mining, and Machine Learning in Astronomy" (2013)
 #   For more information, see http://astroML.github.com
+#   To report a bug or issue, use the following forum:
+#    https://groups.google.com/forum/#!forum/astroml-general
 import numpy as np
 from matplotlib import pyplot as plt
 
@@ -17,6 +21,15 @@ from sklearn.tree import DecisionTreeClassifier
 from astroML.datasets import fetch_rrlyrae_combined
 from astroML.utils import split_samples
 from astroML.utils import completeness_contamination
+
+#----------------------------------------------------------------------
+# This function adjusts matplotlib settings for a uniform feel in the textbook.
+# Note that with usetex=True, fonts are rendered with LaTeX.  This may
+# result in an error if LaTeX is not installed on your system.  In that case,
+# you can set usetex to False.
+from astroML.plotting import setup_text_plots
+setup_text_plots(fontsize=8, usetex=True)
+
 #----------------------------------------------------------------------
 # get data and split into training & testing sets
 X, y = fetch_rrlyrae_combined()
@@ -71,7 +84,7 @@ Z = Z.reshape(xx.shape)
 
 #----------------------------------------------------------------------
 # plot the results
-fig = plt.figure(figsize=(8, 4))
+fig = plt.figure(figsize=(5, 2.5))
 fig.subplots_adjust(bottom=0.15, top=0.95, hspace=0.0,
                     left=0.1, right=0.95, wspace=0.2)
 
@@ -81,7 +94,7 @@ im = ax.scatter(X[-N_plot:, 1], X[-N_plot:, 0], c=y[-N_plot:],
                 s=4, lw=0, cmap=plt.cm.binary, zorder=2)
 im.set_clim(-0.5, 1)
 
-ax.contour(xx, yy, Z, [0.5], linewidths=2., colors='k')
+ax.contour(xx, yy, Z, [0.5], colors='k')
 
 ax.set_xlim(xlim)
 ax.set_ylim(ylim)
@@ -94,8 +107,8 @@ ax.text(0.02, 0.02, "depth = %i" % depths[1],
 
 # plot completeness vs Ncolors
 ax = fig.add_subplot(222)
-ax.plot(Ncolors, completeness[0], 'o-k', label="depth=%i" % depths[0])
-ax.plot(Ncolors, completeness[1], '^--k', label="depth=%i" % depths[1])
+ax.plot(Ncolors, completeness[0], 'o-k', ms=6, label="depth=%i" % depths[0])
+ax.plot(Ncolors, completeness[1], '^--k', ms=6, label="depth=%i" % depths[1])
 
 ax.xaxis.set_major_locator(plt.MultipleLocator(1))
 ax.yaxis.set_major_locator(plt.MultipleLocator(0.2))
@@ -108,10 +121,9 @@ ax.grid(True)
 
 # plot contamination vs Ncolors
 ax = fig.add_subplot(224)
-ax.plot(Ncolors, contamination[0], 'o-k', label="depth=%i" % depths[0])
-ax.plot(Ncolors, contamination[1], '^--k', label="depth=%i" % depths[1])
-ax.legend(prop=dict(size=12),
-          loc='lower right',
+ax.plot(Ncolors, contamination[0], 'o-k', ms=6, label="depth=%i" % depths[0])
+ax.plot(Ncolors, contamination[1], '^--k', ms=6, label="depth=%i" % depths[1])
+ax.legend(loc='lower right',
           bbox_to_anchor=(1.0, 0.79))
 
 ax.xaxis.set_major_locator(plt.MultipleLocator(1))
