@@ -4,11 +4,13 @@ Decision Tree Classification of photometry
 Decision Tree photometric classification of rr-lyrae stars.  This uses averaged
 photometry from the rr-lyrae catalog and stripe 82 standards catalogs.
 """
-# Author: Jake VanderPlas <vanderplas@astro.washington.edu>
+# Author: Jake VanderPlas
 # License: BSD
 #   The figure produced by this code is published in the textbook
 #   "Statistics, Data Mining, and Machine Learning in Astronomy" (2013)
 #   For more information, see http://astroML.github.com
+#   To report a bug or issue, use the following forum:
+#    https://groups.google.com/forum/#!forum/astroml-general
 import numpy as np
 from matplotlib import pyplot as plt
 
@@ -16,6 +18,14 @@ from sklearn.ensemble import RandomForestClassifier
 
 from astroML.datasets import fetch_rrlyrae_mags, fetch_sdss_S82standards
 
+#----------------------------------------------------------------------
+# This function adjusts matplotlib settings for a uniform feel in the textbook.
+# Note that with usetex=True, fonts are rendered with LaTeX.  This may
+# result in an error if LaTeX is not installed on your system.  In that case,
+# you can set usetex to False.
+from astroML.plotting import setup_text_plots
+setup_text_plots(fontsize=8, usetex=True)
+
 
 def load_rrlyrae_data():
     """Load the RR Lyrae data.
@@ -135,7 +145,7 @@ print "contamination", contamination
 
 #----------------------------------------------------------------------
 # plot the results
-plt.figure(figsize=(8, 4))
+plt.figure(figsize=(5, 2.5))
 plt.subplots_adjust(bottom=0.15, top=0.95, hspace=0.0,
                     left=0.1, right=0.95, wspace=0.2)
 
@@ -158,7 +168,7 @@ Z = Z.reshape(xx.shape)
 #from scipy.ndimage import gaussian_filter
 #Z = gaussian_filter(Z, 2)
 
-plt.contour(xx, yy, Z, [0.5], linewidths=2., colors='k')
+plt.contour(xx, yy, Z, [0.5], colors='k')
 
 plt.xlim(xlim)
 plt.ylim(ylim)
@@ -170,8 +180,8 @@ plt.text(0.02, 0.02, "depth = %i" % depths[1],
          transform=ax.transAxes)
 
 ax = plt.subplot(222)
-plt.plot(Ncolors, completeness[0], 'o-k', label="depth=%i" % depths[0])
-plt.plot(Ncolors, completeness[1], '^--k', label="depth=%i" % depths[1])
+plt.plot(Ncolors, completeness[0], 'o-k', ms=6, label="depth=%i" % depths[0])
+plt.plot(Ncolors, completeness[1], '^--k', ms=6, label="depth=%i" % depths[1])
 
 ax.xaxis.set_major_locator(plt.MultipleLocator(1))
 ax.yaxis.set_major_locator(plt.MultipleLocator(0.2))
@@ -183,10 +193,9 @@ plt.ylim(-0.1, 1.1)
 plt.grid(True)
 
 ax = plt.subplot(224)
-plt.plot(Ncolors, contamination[0], 'o-k', label="depth=%i" % depths[0])
-plt.plot(Ncolors, contamination[1], '^--k', label="depth=%i" % depths[1])
-plt.legend(prop=dict(size=12),
-           loc='lower right',
+plt.plot(Ncolors, contamination[0], 'o-k', ms=6, label="depth=%i" % depths[0])
+plt.plot(Ncolors, contamination[1], '^--k', ms=6, label="depth=%i" % depths[1])
+plt.legend(loc='lower right',
            bbox_to_anchor=(1.0, 0.79))
 
 ax.xaxis.set_major_locator(plt.MultipleLocator(1))
