@@ -1,15 +1,22 @@
 """
 K-neighbors Classification of photometry
 ----------------------------------------
-K-nearest-neighbor photometric classification of rr-lyrae stars.
-This uses averaged photometry from the rr-lyrae catalog and stripe 82
-standards catalogs.
+Figure 9.7
+
+K-nearest-neighbor classification for RR Lyrae stars (see caption of figure 9.3
+for details). Here the left panel shows the decision boundary for the model
+based on K = 10 neighbors, and the right panel shows the completeness and
+contamination for both K = 1 and K = 10. With all four colors and K = 10,
+K-neighbors classification achieves a completeness of 0.533 and a contamination
+of 0.240.
 """
-# Author: Jake VanderPlas <vanderplas@astro.washington.edu>
+# Author: Jake VanderPlas
 # License: BSD
 #   The figure produced by this code is published in the textbook
 #   "Statistics, Data Mining, and Machine Learning in Astronomy" (2013)
 #   For more information, see http://astroML.github.com
+#   To report a bug or issue, use the following forum:
+#    https://groups.google.com/forum/#!forum/astroml-general
 import numpy as np
 from matplotlib import pyplot as plt
 from matplotlib import colors
@@ -19,6 +26,14 @@ from astroML.datasets import fetch_rrlyrae_combined
 from astroML.utils import split_samples
 from astroML.utils import completeness_contamination
 
+#----------------------------------------------------------------------
+# This function adjusts matplotlib settings for a uniform feel in the textbook.
+# Note that with usetex=True, fonts are rendered with LaTeX.  This may
+# result in an error if LaTeX is not installed on your system.  In that case,
+# you can set usetex to False.
+from astroML.plotting import setup_text_plots
+setup_text_plots(fontsize=8, usetex=True)
+
 #----------------------------------------------------------------------
 # get data and split into training & testing sets
 X, y = fetch_rrlyrae_combined()
@@ -45,8 +60,7 @@ for k in kvals:
     classifiers.append([])
     predictions.append([])
     for nc in Ncolors:
-        clf = KNeighborsClassifier(n_neighbors=k,
-                                   warn_on_equidistant=False)
+        clf = KNeighborsClassifier(n_neighbors=k)
         clf.fit(X_train[:, :nc], y_train)
         y_pred = clf.predict(X_test[:, :nc])
 
@@ -72,7 +86,7 @@ Z = Z.reshape(xx.shape)
 
 #----------------------------------------------------------------------
 # plot the results
-fig = plt.figure(figsize=(8, 4))
+fig = plt.figure(figsize=(5, 2.5))
 fig.subplots_adjust(bottom=0.15, top=0.95, hspace=0.0,
                     left=0.1, right=0.95, wspace=0.2)
 
@@ -87,7 +101,7 @@ im = ax.imshow(Z, origin='lower', aspect='auto',
                extent=xlim + ylim)
 im.set_clim(0, 2)
 
-ax.contour(xx, yy, Z, [0.5], linewidths=2., colors='k')
+ax.contour(xx, yy, Z, [0.5], colors='k')
 
 ax.set_xlim(xlim)
 ax.set_ylim(ylim)
@@ -101,8 +115,8 @@ ax.text(0.02, 0.02, "k = %i" % kvals[1],
 # plot completeness vs Ncolors
 ax = fig.add_subplot(222)
 
-ax.plot(Ncolors, completeness[0], 'o-k', label='k=%i' % kvals[0])
-ax.plot(Ncolors, completeness[1], '^--k', label='k=%i' % kvals[1])
+ax.plot(Ncolors, completeness[0], 'o-k', ms=6, label='k=%i' % kvals[0])
+ax.plot(Ncolors, completeness[1], '^--k', ms=6, label='k=%i' % kvals[1])
 
 ax.xaxis.set_major_locator(plt.MultipleLocator(1))
 ax.yaxis.set_major_locator(plt.MultipleLocator(0.2))
@@ -115,10 +129,9 @@ ax.grid(True)
 
 # plot contamination vs Ncolors
 ax = fig.add_subplot(224)
-ax.plot(Ncolors, contamination[0], 'o-k', label='k=%i' % kvals[0])
-ax.plot(Ncolors, contamination[1], '^--k', label='k=%i' % kvals[1])
-ax.legend(prop=dict(size=12),
-          loc='lower right',
+ax.plot(Ncolors, contamination[0], 'o-k', ms=6, label='k=%i' % kvals[0])
+ax.plot(Ncolors, contamination[1], '^--k', ms=6, label='k=%i' % kvals[1])
+ax.legend(loc='lower right',
           bbox_to_anchor=(1.0, 0.79))
 
 ax.xaxis.set_major_locator(plt.MultipleLocator(1))
