@@ -1,14 +1,19 @@
 """
 LDA Classification of photometry
 --------------------------------
-LDA photometric classification of rr-lyrae stars.  This uses averaged
-photometry from the rr-lyrae catalog and stripe 82 standards catalogs.
+Figure 9.4
+
+The linear discriminant boundary for RR Lyrae stars (see caption of figure 9.3
+for details). With all four colors, LDA achieves a completeness of 0.672 and a
+contamination of 0.806.
 """
-# Author: Jake VanderPlas <vanderplas@astro.washington.edu>
+# Author: Jake VanderPlas
 # License: BSD
 #   The figure produced by this code is published in the textbook
 #   "Statistics, Data Mining, and Machine Learning in Astronomy" (2013)
 #   For more information, see http://astroML.github.com
+#   To report a bug or issue, use the following forum:
+#    https://groups.google.com/forum/#!forum/astroml-general
 import numpy as np
 from matplotlib import pyplot as plt
 from matplotlib import colors
@@ -19,6 +24,14 @@ from astroML.datasets import fetch_rrlyrae_combined
 from astroML.utils import split_samples
 from astroML.utils import completeness_contamination
 
+#----------------------------------------------------------------------
+# This function adjusts matplotlib settings for a uniform feel in the textbook.
+# Note that with usetex=True, fonts are rendered with LaTeX.  This may
+# result in an error if LaTeX is not installed on your system.  In that case,
+# you can set usetex to False.
+from astroML.plotting import setup_text_plots
+setup_text_plots(fontsize=8, usetex=True)
+
 #----------------------------------------------------------------------
 # get data and split into training & testing sets
 X, y = fetch_rrlyrae_combined()
@@ -66,7 +79,7 @@ Z = Z[:, 1].reshape(xx.shape)
 
 #----------------------------------------------------------------------
 # plot the results
-fig = plt.figure(figsize=(8, 4))
+fig = plt.figure(figsize=(5, 2.5))
 fig.subplots_adjust(bottom=0.15, top=0.95, hspace=0.0,
                     left=0.1, right=0.95, wspace=0.2)
 
@@ -81,7 +94,7 @@ im = ax.imshow(Z, origin='lower', aspect='auto',
                extent=xlim + ylim)
 im.set_clim(0, 1.5)
 
-ax.contour(xx, yy, Z, [0.5], linewidths=2., colors='k')
+ax.contour(xx, yy, Z, [0.5], colors='k')
 
 ax.set_xlim(xlim)
 ax.set_ylim(ylim)
@@ -91,7 +104,7 @@ ax.set_ylabel('$g-r$')
 
 # plot completeness vs Ncolors
 ax = fig.add_subplot(222)
-ax.plot(Ncolors, completeness, 'o-k', c='k', label='unweighted')
+ax.plot(Ncolors, completeness, 'o-k', ms=6, label='unweighted')
 
 ax.xaxis.set_major_locator(plt.MultipleLocator(1))
 ax.yaxis.set_major_locator(plt.MultipleLocator(0.2))
@@ -104,7 +117,7 @@ ax.grid(True)
 
 # plot contamination vs Ncolors
 ax = fig.add_subplot(224)
-ax.plot(Ncolors, contamination, 'o-k', c='k', label='unweighted')
+ax.plot(Ncolors, contamination, 'o-k', ms=6, label='unweighted')
 
 ax.xaxis.set_major_locator(plt.MultipleLocator(1))
 ax.yaxis.set_major_locator(plt.MultipleLocator(0.2))
