@@ -1,15 +1,19 @@
 """
 Logistic Regression of photometry
 ---------------------------------
-Logistic Regression for photometric classification of rr-lyrae stars.
-This uses averaged photometry from the rr-lyrae catalog and stripe 82
-standards catalogs.
+Figure 9.8
+
+Logistic regression for RR Lyrae stars (see caption of figure 9.3 for details).
+With all four colors, logistic regression achieves a completeness of 0.993 and
+a contamination of 0.838.
 """
-# Author: Jake VanderPlas <vanderplas@astro.washington.edu>
+# Author: Jake VanderPlas
 # License: BSD
 #   The figure produced by this code is published in the textbook
 #   "Statistics, Data Mining, and Machine Learning in Astronomy" (2013)
 #   For more information, see http://astroML.github.com
+#   To report a bug or issue, use the following forum:
+#    https://groups.google.com/forum/#!forum/astroml-general
 import numpy as np
 from matplotlib import pyplot as plt
 from matplotlib import colors
@@ -19,6 +23,14 @@ from astroML.datasets import fetch_rrlyrae_combined
 from astroML.utils import split_samples
 from astroML.utils import completeness_contamination
 
+#----------------------------------------------------------------------
+# This function adjusts matplotlib settings for a uniform feel in the textbook.
+# Note that with usetex=True, fonts are rendered with LaTeX.  This may
+# result in an error if LaTeX is not installed on your system.  In that case,
+# you can set usetex to False.
+from astroML.plotting import setup_text_plots
+setup_text_plots(fontsize=8, usetex=True)
+
 #----------------------------------------------------------------------
 # get data and split into training & testing sets
 X, y = fetch_rrlyrae_combined()
@@ -40,8 +52,7 @@ predictions = []
 Ncolors = np.arange(1, X.shape[1] + 1)
 
 for nc in Ncolors:
-    clf = LogisticRegression(class_weight=dict([(i, np.sum(y_train == i))
-                                                for i in (0, 1)]))
+    clf = LogisticRegression(class_weight='auto')
     clf.fit(X_train[:, :nc], y_train)
     y_pred = clf.predict(X_test[:, :nc])
 
@@ -70,7 +81,7 @@ Z = Z.reshape(xx.shape)
 
 #----------------------------------------------------------------------
 # plot the results
-fig = plt.figure(figsize=(8, 4))
+fig = plt.figure(figsize=(5, 2.5))
 fig.subplots_adjust(bottom=0.15, top=0.95, hspace=0.0,
                     left=0.1, right=0.95, wspace=0.2)
 
@@ -85,7 +96,7 @@ im = ax.imshow(Z, origin='lower', aspect='auto',
                extent=xlim + ylim)
 im.set_clim(0, 2)
 
-ax.contour(xx, yy, Z, [0.5], linewidths=2., colors='k')
+ax.contour(xx, yy, Z, [0.5], colors='k')
 
 ax.set_xlim(xlim)
 ax.set_ylim(ylim)
@@ -96,7 +107,7 @@ ax.set_ylabel('$g-r$')
 # plot completeness vs Ncolors
 ax = fig.add_subplot(222)
 
-ax.plot(Ncolors, completeness, 'o-k')
+ax.plot(Ncolors, completeness, 'o-k', ms=6)
 
 ax.xaxis.set_major_locator(plt.MultipleLocator(1))
 ax.yaxis.set_major_locator(plt.MultipleLocator(0.2))
@@ -109,7 +120,7 @@ ax.grid(True)
 
 # plot contamination vs Ncolors
 ax = fig.add_subplot(224)
-ax.plot(Ncolors, contamination, 'o-k')
+ax.plot(Ncolors, contamination, 'o-k', ms=6)
 
 ax.xaxis.set_major_locator(plt.MultipleLocator(1))
 ax.yaxis.set_major_locator(plt.MultipleLocator(0.2))
